# API Reference

## Classes

```{eval-rst}
.. currentmodule:: scitiff

.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

   SciTiffMetadata
   SciTiffMetadataContainer

```

## Top-level functions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:

   save_scitiff
   load_scitiff
   show_metadata
   to_scitiff_image
   validate_scitiff_metadata_container
   concat_mask_as_channels
   concat_stdevs_and_mask_as_channels
   concat_stdevs_as_channels
   resolve_scitiff_channels

```

## Submodules

```{eval-rst}
.. autosummary::
   :toctree: ../generated/modules
   :template: module-template.rst
   :recursive:

   io
   validator
   data

```
